#
# spec file for package openstack-swift-doc
#
# Copyright (c) 2019 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define component swift

%define version_unconverted 2.22.0.dev3

Name:           openstack-%{component}-doc
Version:        2.22.0~dev3
Release:        1.1
Summary:        OpenStack Storage (Swift) - Documentation
License:        Apache-2.0
Group:          Documentation/HTML
Url:            http://openstack.org/projects/compute/
Source:         http://tarballs.openstack.org/swift/swift-master.tar.gz
BuildRequires:  openstack-suse-macros
BuildRequires:  python-PasteDeploy
BuildRequires:  python-Sphinx
BuildRequires:  python-eventlet
BuildRequires:  python-netifaces
BuildRequires:  python-openstackdocstheme
BuildRequires:  python-oslosphinx
BuildRequires:  python-pbr
BuildRequires:  python-simplejson
BuildRequires:  python-swiftclient
BuildRequires:  python-webob
BuildRequires:  python-xattr
BuildRequires:  python-xml
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildArch:      noarch

%description
OpenStack Object Storage (swift) aggregates commodity servers to work
together in clusters for reliable, redundant, and large-scale storage
of static objects.

This package contains documentation files for openstack-swift.

%prep
%setup -q -n %{component}-%{version_unconverted}
%openstack_cleanup_prep
sed -i 's/^warning-is-error.*/warning-is-error = 0/g' setup.cfg

%build
PBR_VERSION=%version_unconverted PYTHONPATH=. sphinx-build -b html doc/source doc/build/html
rm doc/build/html/.buildinfo # Remove unneeded files

%install

%files
%defattr(-,root,root,-)
%doc LICENSE doc/build/html

%changelog
* Sat Mar 23 2019 cloud-devel@suse.de
- Update to version swift-2.20.1.dev157:
  swift (2.21.0, OpenStack Stein release)
  * Change the behavior of the EC reconstructor to perform a
    fragment rebuild to a handoff node when a primary peer responds
    with 507 to the REPLICATE request. This changes EC to match the
    existing behavior of replication when drives fail. After a
    rebalance of EC rings (potentially removing unmounted/failed
    devices), it's most IO efficient to run in handoffs_only mode to
    avoid unnecessary rebuilds.
  * O_TMPFILE support is now detected by attempting to use it
    instead of looking at the kernel version. This allows older
    kernels with backported patches to take advantage of the
    O_TMPFILE functionality.
  * Add slo_manifest_hook callback to allow other middlewares to
    impose additional constraints on or make edits to SLO manifests
    before being written. For example, a middleware could enforce
    minimum segment size or insert data segments.
  * Fixed an issue with multi-region EC policies that caused the EC
    reconstructor to constantly attempt cross-region rebuild
    traffic.
  * Fixed an issue where S3 API v4 signatures would not be validated
    against the body of the request, allowing a replay attack if
    request headers were captured by a malicious third party.
  * Display crypto data/metadata details in swift-object-info.
* Wed Feb 27 2019 cloud-devel@suse.de
- Update to version swift-2.20.1.dev102:
  2.19.1 (rocky stable backports)
  * Prevent PyKMIP's kmip_protocol logger from logging at DEBUG.
    Previously, some versions of PyKMIP would include all wire
    data when the root logger was configured to log at DEBUG; this
    could expose key material in logs. Only the kmip_keymaster was
    affected.
  * Fixed an issue where a failed drive could prevent the container sharder
    from making progress.
  * Fixed a bug in how Swift uses eventlet that was exposed under high
    concurrency.
  2.17.1 (queens stable backports)
  * Fix SLO delete for accounts with non-ASCII names.
  * Fixed an issue in COPY where concurrent requests may have copied the
    wrong data.
  * Fixed a bug in how Swift uses eventlet that was exposed under high
    concurrency.
  2.15.2 (pike stable backports)
  * Fixed a cache invalidation issue related to GET and PUT requests to
    containers that would occasionally cause object PUTs to a container to
    404 after the container had been successfully created.
  * Removed a race condition where a POST to an SLO could modify the
* Sat Dec 15 2018 cloud-devel@suse.de
- Update to version swift-2.19.1.dev244:
  swift (2.20.0)
  * S3 API compatibility updates
  * Swift can now cache the S3 secret from Keystone to use for
    subsequent requests. This functionality is disabled by default but
    can be enabled by setting the `secret_cache_duration` in the s3token
    section of the proxy server config to a number greater than 0.
  * s3api now mimics the AWS S3 behavior of periodically sending
    whitespace characters on a Complete Multipart Upload request to keep
    the connection from timing out. Note that since a request could fail
    after the initial 200 OK response has been sent, it is important to
    check the response body to determine if the request succeeded.
  * s3api now properly handles x-amz-metadata-directive headers on
    COPY operations.
  * s3api now uses concurrency (default 2) to handle multi-delete
    requests. This allows multi-delete requests to be processed much
    more quickly.
  * s3api now mimics some forms of AWS server-side encryption
    based on whether Swift's at-rest encryption functionality is enabled.
    Note that S3 API users are now able to know more about how the
    cluster is configured than they were previously, ie knowledge of
    encryption at-rest functionality being enabled or not.
  * s3api responses now include a '-' in multipart ETags.
* Tue Aug 28 2018 cloud-devel@suse.de
- Update to version swift-2.19.1.dev14:
  swift (2.19.0, OpenStack Rocky)
* Wed Aug 22 2018 cloud-devel@suse.de
- Update to version swift-2.18.1.dev229:
  swift (2.19.0)
  * TempURLs now support IP range restrictions. Please see
    https://docs.openstack.org/swift/latest/middleware.html#client-usage
    for more information on how to use this additional restriction.
  * Add support for multiple root encryption secrets for the trivial
    and KMIP keymasters. This allows operators to rotate encryption
    keys over time without needing to re-encrypt all existing data
    in the cluster. Please see the included sample config files for
    instructions on how to multiple encryption keys.
  * The object updater now supports two configuration settings:
    "concurrency" and "updater_workers". The latter controls how many
    worker processes are spawned, while the former controls how many
    concurrent container updates are performed by each worker
    process. This should speed the processing of async_pendings.
    On upgrade, a node configured with concurrency=N will still handle
    async updates N-at-a-time, but will do so using only one process
    instead of N.
    If you have a config file like this:
    [object-updater]
    concurrency = <N>
    and you want to take advantage of faster updates, then do this:
    [object-updater]
* Mon Aug 20 2018 comurphy@suse.com
- Update to version swift-2.18.1.dev224:
  swift (2.18.0)
  * Added container sharding, an operator controlled feature that
    may be used to shard very large container databases into a
    number of smaller shard containers. This mitigates the issues
    with one large DB by distributing the data across multiple
    smaller databases throughout the cluster. Please read the full
    overview at
    https://docs.openstack.org/swift/latest/overview_container_sharding.html
  * Provide an S3 API compatibility layer. The external "swift3"
    project has been imported into Swift's codebase as the "s3api"
    middleware.
  * Added "emergency mode" hooks in the account and container replicators.
    These options may be used to prioritize moving handoff
    partitions to primary locations more quickly. This helps when
    adding capacity to a ring.
  - Added `-d <devs>` and `-p <partitions>` command line options.
  - Added a handoffs-only mode.
  * Add a multiprocess mode to the object replicator. Setting the
    "replicator_workers" setting to a positive value N will result
    in the replicator using up to N worker processes to perform
    replication tasks. At most one worker per disk will be spawned.
    Worker process logs will have a bit of information prepended so
    operators can tell which messages came from which worker. The
* Sat Feb  3 2018 cloud-devel@suse.de
- Update to version swift-2.16.1.dev191:
  swift (2.17.0)
  * Added symlink objects support.
    Symlink objects reference one other object. They are created by
    creating an empty object with an X-Symlink-Target header. The value of
    the header is of the format <container>/<object>, and the target does
    not need to exist at the time of symlink creation. Cross-account
    symlinks can be created by including the
    X-Symlink-Target-Account header.
    GET and HEAD requests to a symlink will operate on the
    referenced object and require appropriate permission in the
    target container. DELETE and PUT requests will operate on the
    symlink object itself. POST requests are not forwarded to the
    referenced object. POST requests sent to a symlink will result
    in a 307 Temporary Redirect response.
  * Added support for inline data segments in SLO manifests.
    Upgrade impact: during a rolling upgrade, an updated proxy server
    may write a manifest that an out-of-date proxy server will not be
    able to read. This will resolve itself once the upgrade completes
    on all nodes.
  * The tempurl digest algorithm is now configurable, and Swift added
    support for both SHA-256 and SHA-512. Supported tempurl digests
    are exposed to clients in `/info`. Additionally, tempurl signatures
    can now be base64 encoded.
* Tue Dec 12 2017 gosipyan@suse.com 
- Update to version swift-2.16.1.dev21:
  swift (2.16.0)
  * Add checksum to object extended attributes.
  * Let clients request heartbeats during SLO PUTs by including
    the query parameter `heartbeat=on`.
    With heartbeating turned on, the proxy will start its response
    immediately with 202 Accepted then send a single whitespace
    character periodically until the request completes. At that
    point, a final summary chunk will be sent which includes a
    "Response Status" key indicating success or failure and (if
    successful) an "Etag" key indicating the Etag of the resulting
    SLO.
  * Added support for retrieving the encryption root secret from an
    external key management system. In practice, this is currently limited
    to Barbican.
  * Move listing formatting out to a new proxy middleware named
    `listing_formats`. `listing_formats` should be just right of the
    first proxy-logging middleware, and left of most other
    middlewares. If it is not already present, it will be
    automatically inserted for you.
    Note: if you have a custom middleware that makes account or
    container listings, it will only receive listings in JSON format.
  * Log deprecation warning for `allow_versions` in the container
    server config. Configure the `versioned_writes` middleware in
* Sat Sep 16 2017 cloud-devel@suse.de
- Update to version swift-2.15.2.dev57:
    https://docs.openstack.org/swift/latest/logs.html#swift-source for
    https://docs.openstack.org/swift/latest/overview_object_versioning.html.
    https://docs.openstack.org/swift/latest/admin_guide.html
    https://developer.openstack.org/api-ref/object-storage/.
    https://docs.openstack.org/swift/latest/overview_encryption.html.
    found at https://docs.openstack.org/swift/latest/ops_runbook/index.html and
    https://docs.openstack.org/swift/latest/overview_container_sync.html for more details
    https://docs.openstack.org/swift/latest/middleware.html#how-to-enable-object-versioning-in-a-swift-cluster
    Full docs are at https://docs.openstack.org/swift/latest/overview_erasure_code.html
    See https://docs.openstack.org/swift/latest/overview_auth.html for more details.
    swift_source. See https://docs.openstack.org/swift/latest/logs.html for details.
    See https://docs.openstack.org/swift/latest/overview_ring.html
    Please see https://docs.openstack.org/swift/latest/overview_auth.html for
    Full docs are at https://docs.openstack.org/swift/latest/overview_policies.html
    https://docs.openstack.org/swift/latest/overview_auth.html
    https://docs.openstack.org/swift/latest/overview_container_sync.html
    for full information.
    https://docs.openstack.org/swift/latest/crossdomain.html for details
    https://docs.openstack.org/swift/latest/apache_deployment_guide.html
    docs at https://docs.openstack.org/swift/latest/misc.html.
* Wed Aug 23 2017 tbechtold@suse.com
- Fix doc build
* Sat Aug 19 2017 cloud-devel@suse.de
- Update to version swift-2.15.1.dev43:
  swift (2.15.1)
  * Fixed a bug introduced in 2.15.0 where the object reconstructor
    would exit with a traceback if no EC policy was configured.
  * Fixed deadlock when logging from a tpool thread.
    The object server runs certain IO-intensive methods outside the
    main pthread for performance. Previously, if one of those methods
    tried to log, this can cause a crash that eventually leads to an
    object server with hundreds or thousands of greenthreads, all
    deadlocked. The fix is to use a mutex that works across different
    greenlets and different pthreads.
  * The object reconstructor can now rebuild an EC fragment for an
    expired object.
  * Various other minor bug fixes and improvements.
* Fri Jul 28 2017 cloud-devel@suse.de
- Update to version swift-2.14.1.dev183:
  swift (2.15.0)
  * Add Composite Ring Functionality
    A composite ring comprises two or more component rings that are
    combined to form a single ring with a replica count equal to the
    sum of the component rings. The component rings are built
    independently, using distinct devices in distinct regions, which
    means that the dispersion of replicas between the components can
    be guaranteed.
    Composite rings can be used for explicit replica placement and
    "replicated EC" for global erasure codes policies.
    Composite rings support 'cooperative' rebalance which means that
    during rebalance all component rings will be consulted before a
    partition is moved in any component ring. This avoids the same
    partition being simultaneously moved in multiple components.
    We do not yet have CLI tools for creating composite rings, but
    the functionality has been enabled in the ring modules to
    support this advanced functionality. CLI tools will be delivered
    in a subsequent release.
    For further information see the docs at
    <https://docs.openstack.org/swift/latest/overview_ring.html#module-swift.common.ring.composite_builder>
  * The EC reconstructor process has been dramatically improved by
    adding support for multiple concurrent workers. Multiple
    processes are required to get high concurrency, and this change
* Tue Jul 11 2017 tbechtold@suse.com
- update to 2.14.1~a0~dev139
* Thu Apr 27 2017 cloud-devel@suse.de
- Update to version swift-2.13.1.dev153:
  swift (2.14.0)
  * Fixed error where a container drive error resulted in double space
    usage on rest drives. When drive with container or account database
    is unmounted, the bug would create handoff replicas on all remaining
    drives, increasing the drive space used and filling the cluster.
  * Fixed UnicodeDecodeError in the object reconstructor that would
    prevent objects with non-ascii names from being reconstructed and
    caused the reconstructor process to hang.
  * EC Fragment Duplication - Foundational Global EC Cluster Support.
  * Fixed encoding issue in ssync where a mix of ascii and non-ascii
    metadata values would cause an error.
  * `name_check` and `cname_lookup` keys have been added to `/info`.
  * Add Vary: headers for CORS responses.
  * Always set Swift processes to use UTC.
  * Prevent logged traceback in object-server on client disconnect for
    chunked transfers to replicated policies.
  * Removed per-device reconstruction stats. Now that the reconstructor
    is shuffling parts before going through them, those stats no longer
    make sense.
  * Log correct status code for conditional requests.
* Thu Mar  9 2017 cloud-devel@suse.de
- Update to version swift-2.13.1.dev44:
    found at http://docs.openstack.org/developer/swift/ops_runbook/index.html and
    http://docs.openstack.org/developer/swift/overview_container_sync.html for more details
    http://docs.openstack.org/developer/swift/middleware.html#how-to-enable-object-versioning-in-a-swift-cluster
    Full docs are at http://docs.openstack.org/developer/swift/overview_erasure_code.html
    See http://docs.openstack.org/developer/swift/overview_auth.html for more details.
    swift_source. See http://docs.openstack.org/developer/swift/logs.html for details.
    Please see http://docs.openstack.org/developer/swift/overview_auth.html for
    Full docs are at http://docs.openstack.org/developer/swift/overview_policies.html
    http://docs.openstack.org/developer/swift/overview_auth.html
    http://docs.openstack.org/developer/swift/overview_container_sync.html for full
* Fri Feb 17 2017 cloud-devel@suse.de
- Update to version swift-2.12.1.dev107:
  swift (2.13.0, OpenStack Ocata)
  * Improvements in key parts of the consistency engine
  - Improved performance by eliminating an unneeded directory
    structure hash.
  - Optimized the common case for hashing filesystem trees, thus
    eliminating a lot of extraneous disk I/O.
  - Updated the `hashes.pkl` file format to include timestamp information
    for race detection. Also simplified hashing logic to prevent race
    conditions and optimize for the common case.
  - The erasure code reconstructor will now shuffle work jobs across all
    disks instead of going disk-by-disk. This eliminates single-disk I/O
    contention and allows continued scaling as concurrency is increased.
  - Erasure code reconstruction handles moving data from handoff nodes
    better. Instead of moving the data to another handoff, it waits
    until it can be moved to a primary node.
    Upgrade Impact: If you upgrade and roll back, you must delete all
    `hashes.pkl` files.
  * If using erasure coding with ISA-L in rs_vand mode and 5 or more parity
    fragments, Swift will emit a warning. This is a configuration that is
    known to harm data durability. In a future release, this warning will be
    upgraded to an error unless the policy is marked as deprecated. All data
    in an erasure code storage policy using isa_l_rs_vand with 5 or more
* Thu Dec 15 2016 cloud-devel@suse.de
- Update to version swift-2.11.1.dev70:
  swift (2.12.0)
  * Ring files now include byteorder information about the endian of
    the machine used to generate the file, and the values are
    appropriately byteswapped if deserialized on a machine with a
    different endianness.
    Newly created ring files will be byteorder agnostic, but
    previously generated ring files will still fail on different
    endian architectures. Regenerating older ring files will cause
    them to become byteorder agnostic. The regeneration of the ring
    files will not cause any new data movement. Newer ring files
    will still be usable by older versions of Swift (on machines
    with the same endianness--this maintains existing behavior).
  * All 416 responses will now include a Content-Range header with
    an unsatisfied-range value. This allows the caller to know the
    valid range request value for an object.
  * TempURLs now support a validation against a common prefix. A
    prefix-based signature grants access to all objects which share the
    same prefix. This avoids the creation of a large amount of signatures,
    when a whole container or pseudofolder is shared.
  * Correctly handle deleted files with if-none-match requests.
  * Correctly send 412 Precondition Failed if a user sends an
    invalid copy destination. Previously Swift would send a 500
    Internal Server Error.
* Sat Nov 19 2016 cloud-devel@suse.de
- Update to version swift-2.11.1.dev5:
  swift (2.11.0)
  * We have made significant improvements and changes to the erasure
    code implementation.
  - Instead of using a separate .durable file to indicate the
    durable status of an EC fragment archive, we rename the .data
    to include a durable marker in the filename. This saves one
    inode for every EC .data file. Existing .durable files will not
    be removed, and they will continue to work just fine.
    Note that after writing EC data with Swift 2.11.0 or later, that
    data will not be accessible to earlier versions of Swift.
  - Closed a bug where ssync may have written bad fragment data in
    some circumstances. A check was added to ensure the correct number
    of bytes is written for a fragment before finalizing the write.
    Also, erasure coded fragment metadata will now be validated on read
    requests and, if bad data is found, the fragment will be quarantined.
  - The improvements to EC reads made in Swift 2.10.0 have also been
    applied to the reconstructor. This allows fragments to be rebuilt
    in more circumstances, resulting in faster recovery from failures.
  - WARNING: If you are using the ISA-L library for erasure codes,
    please upgrade to liberasurecode 1.3.1 (or later) as soon as
    possible. If you are using isa_l_rs_vand with more than 4 parity,
    please read https://bugs.launchpad.net/swift/+bug/1639691 and take
    necessary action.
* Sat Sep 24 2016 cloud-devel@suse.de
- Update to version swift-2.9.1.dev281:
  swift (2.10.0, OpenStack Newton)
  * Object versioning now supports a "history" mode in addition to
    the older "stack" mode. The difference is in how DELETE requests
    are handled. For full details, please read
    http://docs.openstack.org/developer/swift/overview_object_versioning.html.
  * New config variables to change the schedule priority and I/O
    scheduling class. Servers and daemons now understand
    `nice_priority`, `ionice_class`, and `ionice_priority` to
    schedule their relative importance. Please read
    http://docs.openstack.org/developer/swift/deployment_guide.html
    for full config details.
  * On newer kernels (3.15+ when using xfs), Swift will use the O_TMPFILE
    flag when opening a file instead of creating a temporary file
    and renaming it on commit. This makes the data path simpler and
    allows the filesystem to more efficiently optimize the files on
    disk, resulting in better performance.
  * Erasure code GET performance has been significantly
    improved in clusters that are not completely healthy.
  * Significant improvements to the api-ref doc available at
    http://developer.openstack.org/api-ref/object-storage/.
  * A PUT or POST to a container will now update the container's
    Last-Modified time, and that value will be included in a
    GET/HEAD response.
* Wed Sep 21 2016 mjura@suse.com
- Update to version 2.9.1.dev270
* Tue Sep  6 2016 tbechtold@suse.com
- Update to version 2.9.1.dev209
* Thu Jul 14 2016 cloud-devel@suse.de
- Update to version swift-2.8.1.dev93:
  swift (2.9.0)
  * Swift now supports at-rest encryption. This feature encrypts all
    object data and user-set object metadata as it is sent to the cluster.
    This feature is designed to prevent information leaks if a hard drive
    leaves the cluster. The encryption is transparent to the end-user.
    At-rest encryption in Swift is enabled on the proxy server by
    adding two middlewares to the pipeline. The `keymaster` middleware
    is responsible for managing the encryption keys and the `encryption`
    middleware does the actual encryption and decryption.
    Existing clusters will continue to work without enabling
    encryption. Although enabling this feature on existing clusters
    is supported, best practice is to enable this feature on new
    clusters when the cluster is created.
    For more information on the details of the at-rest encryption
    feature, please see the docs at
    http://docs.openstack.org/developer/swift/overview_encryption.html.
  * `swift-recon` can now be called with more than one server type.
  * Fixed a bug where non-ascii names could cause an error in logging
    and cause a 5xx response to the client.
  * The install guide and API reference have been moved into Swift's
    source code repository.
  * Various other minor bug fixes and improvements.
* Tue Jun  7 2016 cloud-devel@suse.de
- Update to version swift-2.7.1.dev184:
  swift (2.8.0)
  * Allow concurrent bulk deletes for server-side deletes of static
    large objects. Previously this would be single-threaded and each
    DELETE executed serially. The new `delete_concurrency` value
    (default value is 2) in the `[filter:slo]` and `[filter:bulk]`
    sections of the proxy server config controls the concurrency
    used to perform the DELETE requests for referenced segments. The
    default value is recommended, but setting the value to 1
    restores previous behavior.
  * Refactor server-side copy as middleware
    The COPY verb is now implemented in the `copy` middleware instead
    of in the proxy server code. If not explicitly added, the server
    side copy middleware is auto-inserted to the left of `dlo`, `slo`
    and `versioned_writes` middlewares in the proxy server pipeline.
    As a result, dlo and slo `copy_hooks` are no longer required. SLO
    manifests are now validated when copied so when copying a
    manifest to another account the referenced segments must be
    readable in that account for the manifest copy to succeed
    (previously this validation was not made, meaning the manifest
    was copied but could be unusable if the segments were not
    readable).
    With this change, there should be no change in functionality or
    existing behavior.
  * `fallocate_reserve` can now be a percentage (a value ending in "%%"),
    and the default has been adjusted to "1%%".
* Thu Mar 24 2016 cloud-devel@suse.de
- Update to version swift-2.6.1.dev262:
  swift (2.7.0, OpenStack Mitaka)
  * Bump PyECLib requirement to >= 1.2.0
  * Update container on fast-POST
    "Fast-POST" is the mode where `object_post_as_copy` is set to
    `False` in the proxy server config. This mode now allows for
    fast, efficient updates of metadata without needing to fully
    recopy the contents of the object. While the default still is
    `object_post_as_copy` as True, the plan is to change the default
    to False and then deprecate post-as-copy functionality in later
    releases. Fast-POST now supports container-sync functionality.
  * Add concurrent reads option to proxy.
    This change adds 2 new parameters to enable and control concurrent
    GETs in Swift, these are `concurrent_gets` and `concurrency_timeout`.
    `concurrent_gets` allows you to turn on or off concurrent
    GETs; when on, it will set the GET/HEAD concurrency to the
    replica count. And in the case of EC HEADs it will set it to
    ndata. The proxy will then serve only the first valid source to
    respond. This applies to all account, container, and replicated
    object GETs and HEADs. For EC only HEAD requests are affected.
    The default for `concurrent_gets` is off.
    `concurrency_timeout` is related to `concurrent_gets` and is
    the amount of time to wait before firing the next thread. A
    value of 0 will fire at the same time (fully concurrent), but
* Fri Feb 26 2016 cloud-devel@suse.de
- Update to version swift-2.6.1.dev138:
  swift (2.6.0)
  * Dependency changes
  - Updated minimum version of eventlet to 0.17.4 to support IPv6.
  - Updated the minimum version of PyECLib to 1.0.7.
  * The ring rebalancing algorithm was updated to better handle edge cases
    and to give better (more balanced) rings in the general case. New rings
    will have better initial placement, capacity adjustments will move less
    data for better balance, and existing rings that were imbalanced should
    start to become better balanced as they go through rebalance cycles.
  * Added container and account reverse listings.
    A GET request to an account or container resource with a "reverse=true"
    query parameter will return the listing in reverse order. When
    iterating over pages of reverse listings, the relative order of marker
    and end_marker are swapped.
  * Storage policies now support having more than one name.
    This allows operators to fix a typo without breaking existing clients,
    or, alternatively, have "short names" for policies. This is implemented
    with the "aliases" config key in the storage policy config in
    swift.conf. The aliases value is a list of names that the storage
    policy may also be identified by. The storage policy "name" is used to
    report the policy to users (eg in container headers). The aliases have
    the same naming restrictions as the policy's primary name.
* Sun Oct  4 2015 cloud-devel@suse.de
- Update to version swift-2.4.1.dev70:
  swift (2.5.0, OpenStack Liberty)
  * Added the ability to specify ranges for Static Large Object (SLO)
    segments.
  * Replicator configs now support an "rsync_module" value to allow
    for per-device rsync modules. This setting gives operators the
    ability to fine-tune replication traffic in a Swift cluster and
    isolate replication disk IO to a particular device. Please see
    the docs and sample config files for more information and
    examples.
  * Significant work has gone in to testing, fixing, and validating
    Swift's erasure code support at different scales.
  * Swift now emits StatsD metrics on a per-policy basis.
  * Fixed an issue with Keystone integration where a COPY request to a
    service account may have succeeded even if a service token was not
    included in the request.
  * Ring validation now warns if a placement partition gets assigned to the
    same device multiple times. This happens when devices in the ring are
    unbalanced (e.g. two servers where one server has significantly more
    available capacity).
  * Various other minor bug fixes and improvements.
* Wed Sep  2 2015 cloud-devel@suse.de
- Update to version swift-2.3.1.dev356:
  swift (2.4.0)
  * Dependency changes
  - Added six requirement. This is part of an ongoing effort to add
    support for Python 3.
  - Dropped support for Python 2.6.
  * Config changes
  - Recent versions of Python restrict the number of headers allowed in a
    request to 100. This number may be too low for custom middleware. The
    new "extra_header_count" config value in swift.conf can be used to
    increase the number of headers allowed.
  - Renamed "run_pause" setting to "interval" (current configs with
    run_pause still work). Future versions of Swift may remove the
    run_pause setting.
  * Versioned writes middleware
    The versioned writes feature has been refactored and reimplemented as
    middleware. You should explicitly add the versioned_writes middleware to
    your proxy pipeline, but do not remove or disable the existing container
    server config setting ("allow_versions"), if it is currently enabled.
    The existing container server config setting enables existing
    containers to continue being versioned. Please see
    http://swift.openstack.org/middleware.html#how-to-enable-object-versioning-in-a-swift-cluster
    for further upgrade notes.
* Fri Aug 21 2015 cloud-devel@suse.de
- Update to version swift-2.3.1.dev307:
  swift (2.3.0, OpenStack Kilo)
  swift (2.2.0, OpenStack Juno)
  swift (1.13.1, OpenStack Icehouse)
  swift (1.10.0, OpenStack Havana)
  swift (1.8.0, OpenStack Grizzly)
  swift (1.7.4, OpenStack Folsom)
  swift (1.4.8, OpenStack Essex)
  swift (1.4.3, OpenStack Diablo)
  Changelog entries for previous versions are incomplete
  swift (1.3.0, OpenStack Cactus)
  swift (1.2.0, OpenStack Bexar)
  swift (1.0.0, OpenStack Austin)
* Mon May  4 2015 vuntz@opensuse.org
- Update to version swift-2.3.1.dev12:
  swift (2.3.0)
  * Erasure Code support (beta)
    Swift now supports an erasure-code (EC) storage policy type. This allows
    deployers to achieve very high durability with less raw capacity as used
    in replicated storage. However, EC requires more CPU and network
    resources, so it is not good for every use case. EC is great for storing
    large, infrequently accessed data in a single region.
    Swift's implementation of erasure codes is meant to be transparent to
    end users. There is no API difference between replicated storage and
    EC storage.
    To support erasure codes, Swift now depends on PyECLib and
    liberasurecode. liberasurecode is a pluggable library that allows for
    the actual EC algorithm to be implemented in a library of your choosing.
    As a beta release, EC support is nearly fully feature complete, but it
    is lacking support for some features (like multi-range reads) and has
    not had a full performance characterization. This feature relies on
    ssync for durability. Deployers are urged to do extensive testing and
    not deploy production data using an erasure code storage policy.
    Full docs are at http://swift.openstack.org/overview_erasure_code.html
  * Add support for container TempURL Keys.
  * Make more memcache options configurable. connection_timeout,
    pool_timeout, tries, and io_timeout are all now configurable.
* Fri Jan 30 2015 cloud-devel@suse.de
- Update to version swift-2.2.2rc1.post9:
  swift (2.2.2)
  * Data placement changes
    This release has several major changes to data placement in Swift in
    order to better handle different deployment patterns. First, with an
    unbalance-able ring, less partitions will move if the movement doesn't
    result in any better dispersion across failure domains. Also, empty
    (partition weight of zero) devices will no longer keep partitions after
    rebalancing when there is an unbalance-able ring.
    Second, the notion of "overload" has been added to Swift's rings. This
    allows devices to take some extra partitions (more than would normally
    be allowed by the device weight) so that smaller and unbalanced clusters
    will have less data movement between servers, zones, or regions if there
    is a failure in the cluster.
    Finally, rings have a new metric called "dispersion". This is the
    percentage of partitions in the ring that have too many replicas in a
    particular failure domain. For example, if you have three servers in a
    cluster but two replicas for a partition get placed onto the same
    server, that partition will count towards the dispersion metric. A
    lower value is better, and the value can be used to find the proper
    value for "overload".
    The overload and dispersion metrics have been exposed in the
    swift-ring-build CLI tools.
    See http://docs.openstack.org/developer/swift/overview_ring.html
    for more info on how data placement works now.
* Tue Dec 16 2014 cloud-devel@suse.de
- Update to version swift-2.2.1c1.2.g8bbb50d:
  swift (2.2.1)
  * Swift now rejects object names with Unicode surrogates.
  * Return 403 (instead of 413) on unauthorized upload when over account
    quota.
  * Fix a rare condition when a rebalance could cause swift-ring-builder
    to crash. This would only happen on old ring files when "rebalance"
    was the first command run.
  * Storage node error limits now survive a ring reload.
  * Speed up reading and writing xattrs for object metadata by using larger
    xattr value sizes. The change is moving from 254 byte values to 64KiB
    values. There is no migration issue with this.
  * Deleted containers beyond the reclaim age are now properly reclaimed.
  * Full Simplified Chinese translation (zh_CN locale) for errors and logs.
  * Container quota is now properly enforced during cross-account COPY.
  * ssync replication now properly uses the configured replication_ip.
  * Fixed issue were ssync did not replicate custom object headers.
  * swift-drive-audit now has the 'unmount_failed_device' config option
    (default to True) that controls if the process will unmount failed
    drives or not.
* Sat Oct  4 2014 cloud-devel@suse.de
- Update to version swift-2.1.0.126.g94fd95b:
  swift (2.2.0)
  * Added support for Keystone v3 auth.
    Keystone v3 introduced the concept of "domains" and user names
    are no longer unique across domains. Swift's Keystone integration
    now requires that ACLs be set on IDs, which are unique across
    domains, and further restricts setting new ACLs to only use IDs.
    Please see http://swift.openstack.org/overview_auth.html for
    more information on configuring Swift and Keystone together.
  * Swift now supports server-side account-to-account copy. Server-
    side copy in Swift requires the X-Copy-From header (on a PUT)
    or the Destination header (on a COPY). To initiate an account-to-
    account copy, the existing header value remains the same, but the
    X-Copy-From-Account header (on a PUT) or the Destination-Account
    (on a COPY) are used to indicate the proper account.
  * Limit partition movement when adding a new placement tier.
    When adding a new placement tier (server, zone, or region), Swift
    previously attempted to move all placement partitions, regardless
    of the space available on the new tier, to ensure the best possible
    durability. Unfortunately, this could result in too many partitions
    being moved all at once to a new tier. Swift's ring-builder now
    ensures that only the correct number of placement partitions are
    rebalanced, and thus makes adding capacity to the cluster more
    efficient.
* Sun Aug 24 2014 cloud-devel@suse.de
- Update to version swift-2.0.0.148.g8d02147:
  swift (2.1.0)
  * swift-ring-builder placement was improved to allow gradual addition
    of new regions without causing a massive migration of data to the new
    region. The change was to prefer device weight first, then look at
    failure domains.
  * Logging updates
  - Eliminated "Handoff requested (N)" log spam.
  - Added process pid to the end of storage node log lines.
  - Container auditor now logs a warning if the devices path contains a
    non-directory.
  - Object daemons now send a user-agent string with their full name.
  * 412 and 416 responses are no longer tracked as errors in the StatsD
    messages from the backend servers.
  * Parallel object auditor
    The object auditor can now be controlled with a "concurrency" config
    value that allows multiple auditor processes to run at once. Using
    multiple parallel auditor processes can speed up the overall auditor
    cycle time.
  * The object updater will now concurrently update each necessary node
    in a new greenthread.
* Fri Jun 27 2014 dmueller@suse.com
- Update to version swift-2.0.0.rc1.12.g53577c5:
  swift (2.0.0)
  * Storage policies
    Storage policies allow deployers to configure multiple object rings
    and expose them to end users on a per-container basis. Deployers
    can create policies based on hardware performance, regions, or other
    criteria and independently choose different replication factors on
    them. A policy is set on a Swift container at container creation
    time and cannot be changed.
    Full docs are at http://swift.openstack.org/overview_policies.html
  * Add profiling middleware in Swift
    The profile middleware provides a tool to profile Swift
    code on the fly and collects statistical data for performance
    analysis. A native simple Web UI is also provided to help
    query and visualize the data.
  * Add --quoted option to swift-temp-url
  * swift-recon now supports checking the md5sum of swift.conf, which
    helps deployers verify configurations are consistent across a cluster.
  * Users can now set the transaction id suffix by passing in
    a value in the X-Trans-Id-Extra header.
  * New log_max_line_length option caps the maximum length of a log line.
* Fri Apr  4 2014 cloud-devel@suse.de
- Update to version swift-1.13.0.116.gbf292ae:
  swift (1.13.1)
  * Change the behavior of CORS responses to better match the spec
    A new proxy config variable (strict_cors_mode, default to True)
    has been added. Setting it to False keeps the old behavior. For
    an overview of old versus new behavior, please see
    https://review.openstack.org/#/c/69419/
  * Invert the responsibility of the two instances of proxy-logging in
    the proxy pipeline
    The first proxy_logging middleware instance to receive a request
    in the pipeline marks that request as handling it. So now, the
    left most proxy_logging middleware handles logging for all
    client requests, and the right most proxy_logging middleware
    handles all other requests initiated from within the pipeline to
    its left. This fixes logging related to large object
    requests not properly recording bandwidth.
  * Added swift-container-info and swift-account-info tools
  * Allow specification of object devices for audit
  * Dynamic large object COPY requests with ?multipart-manifest=get
    now work as expected
  * When a client is downloading a large object and one of the segment
    reads gets bad data, Swift will now immediately abort the request.
* Tue Apr  1 2014 cloud-devel@suse.de
- Update to version swift-1.13.0.91.g917cf9e:
    replication. Can also configure how many remote nodes a storage node
* Sat Mar 22 2014 cloud-devel@suse.de
- Update to version 1.10.1:
  + The openstack-swift service user is going to be renamed to swift
* Tue Feb 25 2014 cloud-devel@suse.de
- Update to version swift-1.12.0.111.g58fda94:
  swift (1.13.0)
  * Account-level ACLs and ACL format v2
    Accounts now have a new privileged header to represent ACLs or
    any other form of account-level access control. The value of
    the header is a JSON dictionary string to be interpreted by the
    auth system. A reference implementation is given in TempAuth.
    Please see the full docs at
    http://swift.openstack.org/overview_auth.html
  * Added a WSGI environment flag to stop swob from always using
    absolute location. This is useful if middleware needs to use
    out-of-spec Location headers in a response.
  * Container sync proxies now support simple load balancing
  * Config option to lower the timeout for recoverable object GETs
  * Add a way to ratelimit all writes to an account
  * Allow multiple storage_domain values in cname_lookup middleware
  * Moved all DLO functionality into middleware
    The proxy will automatically insert the dlo middleware at an
    appropriate place in the pipeline the same way it does with the
    gatekeeper middleware. Clusters will still support DLOs after upgrade
    even with an old config file that doesn't mention dlo at all.
* Fri Jan 17 2014 speilicke@suse.com
- Add missing requirement on python-pbr
* Tue Dec 10 2013 opensuse-cloud@opensuse.org
- Update to version 1.10.0.198.gba5fe5f+git.1386670195.ba5fe5f:
  + Prevent early auth deny in tempauth when using swift3 middleware.
  + Remove swift-bench
  + Update handoff algorithm to use IP/port pairs
  + Preserve closeability of app iterables
  + Opt out of the service catalog
  + fix expired object deletion
  + Allow access to the in-memory object server
  + Fixed a failing test on my saio
  + Override spelling of tempauth test name
  + Fix HEAD tempurls
  + Release notes for Swift 1.11.0
  + Stop mutating PATH_INFO in proxy server
  + make test tooling less opinionated
  + clarify the current state of the DiskFile API
  + Use files in the source tree instead of cut/paste
* Thu Dec  5 2013 speilicke@suse.com
- Update to version 1.10.0:
  + Inital commitReplace resetswift script with proper version
  + Drop README
  + Make sure mount point exists
  + Point to correct storage directory in configuration files
  + Add missing object-expirer.conf
  + Use variable
* Fri Jul 19 2013 dmueller@suse.com
- adjust rm command
* Sat Apr 27 2013 opensuse-cloud@opensuse.org
- Update to version 1.8.1+git.1367020840.1b9b989:
  + copy X-Delete-At unless X-Fresh-Metadata: true is supplied on an object copy
* Fri Apr 26 2013 opensuse-cloud@opensuse.org
- Update to version 1.8.1+git.1366970830.55c817c:
  + Fixing /etc/swift.conf-sample to include
  + Add auth_version to dispersion.conf.5
* Tue Apr 23 2013 opensuse-cloud@opensuse.org
- Update to version 1.8.1+git.1366754395.5d52d2d:
  + Made colons quote-safe in logs; mainly for ipv6
* Tue Apr 23 2013 opensuse-cloud@opensuse.org
- Update to version 1.8.1+git.1366675446.7f534fa:
  + fix dict duplicated key
* Mon Apr 22 2013 opensuse-cloud@opensuse.org
- Update to version 1.8.1+git.1366638629.f63dc07:
  + Change logger name to module itself instead of root
  + Add x-remove-versions-location for feature: disable versioning
  + Fix reading xattrs in object-server's unittests.
  + Fix container-server sorting for manifest listings.
  + SLO multipart-manifest=get returns incorrect Content-Type
  + Change setup.cfg style.
  + Update documentation for account_quota middleware
  + add unit tests for db_replicator
  + Allow a configurable set of TempURL methods
  + directory /var/cache/swift /srv/node should be created.
  + Allow all headers requested for CORS.
  + Bug in SLO with multipart-manifest=get content type.
  + Refactored lists of nodes to contact for requests
  + objects md5-collisions
  + Adding a new optional variable called trans_id_suffix
  + Account Quota Correction
  + Correcting output of swift-ring-builder
  + fix email address
  + fix probe tests to work in a VM using mount_check
  + Refactoring format_device function
  + slobjects can not be made of other slobjects
  + Expirer now quotes names when deleting
  + fix slo docs
  + Drop cache after fsync
  + Extra safety on account-level DELETE
* Tue Apr  2 2013 opensuse-cloud@opensuse.org
- Update to version 1.8.1+git.1364897054.01a5a47:
  + additional unit test coverage for container/server.py
  + Fixing SLO range requests
  + fixed some minor things in tests that pyflakes complained about
  + fixes some problems pyflakes complains about
  + updated AUTHORS and CHANGELOG
  + Dynamic Large Object sleeps too much
* Sun Mar 24 2013 cloud-devel@suse.de
- Update to version 1.8.1+git.1364083378.a979c80:
  + Fix for unicode issues in staticweb
  + instruction command was not documented in right format.
  + Fix bugs in bulk and slo and small doc change.
  + Add support for Hash Prefix
* Thu Mar 21 2013 cloud-devel@suse.de
- Update to version 1.8.1+git.1363880673.7df4323:
  + Improved container-sync resiliency
  + Give friendly notification in swift-get-nodes
  + Permit functional tests against Swift with Keystone
  + Fix crash in swift-ring-builder's list_parts command.
  + Small clarification to swift-recon section of admin guide.
  + swift-ring-builder blows up when not supported command requested.
  + Basic ring builder validation.
  + Instruction for multi node setup misses /var/run/swift creation
  + increase unit test coverage on account server
  + AUTHORS/CHANGELOG uploades for the next release
  + version bump for 1.8.1
  + Use role in insensitive case in keystoneauth.
  + fix stupid bug with bulk delete max items
  + Fix misspelled variable.
  + Fix for attempted COPY of objects gt MAX_FILE_SIZE
* Sun Mar 17 2013 cloud-devel@suse.de
- Update to version 1.7.7+git.1363520288.c2f8f00:
  + Add tests and doc entry for request.environ[reseller_request]
  + Add missing CONTRIBUTING.md to source tarball
  + Add a region tier to Swift's ring.
  + Fix swift-ring-builder's list_parts command.
  + Remove check for valid Origin for the "actual request".
  + Fix format device
* Wed Mar 13 2013 cloud-devel@suse.de
- Update to version 1.7.7+git.1363132994.f6d1fa1:
  + Fixed bug with account_info
* Mon Mar 11 2013 cloud-devel@suse.de
- Start using obs-service-github_tarballs
* Mon Mar 11 2013 cloud-devel@suse.de
- Update to version 1.7.7+git.1363001105.5e427e5:
  + Account and container info fixes and improvement.
  + timing-based affinity sorting for primary replicas
  + Fixed formpost QUERY_STRING bugs.
  + Adding speed limit options for DB auditor
  + Allow acl with a valid token.
  + Add tests on keystone for invalid path requests.
  + Add cache=swift.cache for authtoken example.
  + Make rings' replica counts adjustable.
  + Improve bin/swift-account-audit
  + Correct docstring for swift.common.ring.utils.build_tier_tree and add
  + Fix descriptions in sample configs.
  + Add debug level logs for TempAuth.authorize.
  + Move the swift.1 manpage to python-swiftclient
  + Account Server: Refactor HEAD request handler
  + Force log entries to be one line
  + Adding a quick note to helper functions so its clear what they do and
  + Updating classifiers status to stable and clean up
  + make swift fsync
  + Added per disk PUT timing monitoring support.
  + Remove reduant check of list.
  + TempURL filename options; bug fixes
  + Static Large Object Support
  + Updated get_more_nodes algorithm
  + David Hadas email address has been changed.
  + Spread handoffs out better around zones.
  + Fix misspelled variable name
  + Support listing endpoints for an object.
  + Support tests for Apache
  + simplify the chexor function
  + Fix some unreadable code.
  + Account quotas
  + Add exception to swift-drive-audit if no date in line.
* Sun Feb 24 2013 cloud-devel@suse.de
- Update to version 1.7.7+git.1361729875.d1381ba:
  + Change in swift-drive-audit handling log rotation.
  + Adds first-byte latency timings for GET requests.
  + Documentation fixups
* Fri Feb 22 2013 saschpe@suse.de
- BuildRequire openstack-suse-macros instead of openstack-macros
* Mon Feb 18 2013 cloud-devel@suse.de
- Update to version 1.7.7+git.1361180780.e88ff34:
  + Make statsd sample rate behave better.
  + Fixed bug in domain_remap and cname_lookup middleware
  + Deprecate is_admin feature.
  + Allow change the endpoint_type when use swift-dispersion tools
  + Made internal client handle failed requests better
  + Change the flag set to specify bulk delete and expand archives from a HTTP
  + Fixed some swift-recon typos
  + minor development doc changes
  + Use a doubled proxy-logging instead of each middleware handling it
  + Add generated keystone documentation to misc.rst.
  + Replaces Copyright statements for LLC with Foundation, removes date.
  + Fix spelling mistakes
  + log message in exception level when path encoding errors happen.
  + Swift MemcacheRing (set) interface is incompatible fixes
  + fix large objects with unicode
  + Cleanup of file permissions
* Mon Feb  4 2013 cloud-devel@suse.de
- Start using obs-service-github_tarballs
* Mon Feb  4 2013 cloud-devel@suse.de
- Update to version 1.7.7+git.1359979321.ec084de:
  + Fix keystoneauth with OPTIONS headers (eg: CORS)
  + Add wsgify and split_path utilities to swob
  + Add optional locking to swift-ring-builder
  + Handle access_log_headers in proxy_logging
  + Added fallocate_reserve option
  + Allow rebalance to take a seed.
  + Remove tempauth allowed_sync_hosts conf option
  + Cleanup based on pyflakes.
  + Deterministic, repeatable serialization for rings.
  + Optimize the ring builder's _reassign_parts() method.
* Mon Jan 28 2013 cloud-devel@suse.de
- Update to version 1.7.7+git.1359365000.2f663ff:
  + Allow for multiple X-(Account|Container)-* headers.
  + Update auto-generated docs
  + Add more command-line options to swift-bench.
  + Add handler for CORS "actual requests"
  + Bulk Requests: auto extract archive and bulk delete middleware.
* Wed Jan 23 2013 cloud-devel@suse.de
- Update to version 1.7.7+git.1358959291.f2941b0:
  + Add --run-dir switch to swift-init
  + Fix superfluous GET requests in swift-bench.
  + prevent irregular auth_prefix config in tempauth
  + Validate numericness of ports in builder files.
* Mon Jan 21 2013 cloud-devel@suse.de
- Update to version 1.7.7+git.1358760990.6c5fc3c:
  + consistency and grammatical tweaks
  + Fix HEAD request response when request not given to response.
  + Fixed bug in object replicator
  + Add container-sync to container-server.conf doc.
  + Some optimizations for ring rebalancing.
  + Make object-auditor to use one logger
  + swob refactors needed for sos
  + get swob.Request.blank to parse path
  + authors and changelog update for swift 1.7.6
  + version bump to 1.7.7-dev
* Mon Jan  7 2013 cloud-devel@suse.de
- Start using obs-service-github_tarballs
* Thu Nov 15 2012 saschpe@suse.de
- Use openstack-macros
* Tue Nov 13 2012 saschpe@suse.de
- Initial package, split out from openstack-swift.spec
